@@ -155,12 +155,14 @@ module ChefZero
           'checksums' => {}
         },
         'nodes' => {},
+        'policies' => {},
+        'policy_groups' => {},
         'roles' => {},
         'sandboxes' => {},
         'users' => {},
 
         'org' => {},
-        'containers' => %w(clients containers cookbooks data environments groups nodes roles sandboxes),
+        'containers' => %w(clients containers cookbooks data environments groups nodes roles sandboxes policies cookbook_artifacts),
         'groups' => %w(admins billing-admins clients users),
         'association_requests' => {}
       }
@@ -378,11 +380,12 @@ module ChefZero
           # Non-default containers do not get superusers added to them,
           # because reasons.
           unless path.size == 4 && path[0] == 'organizations' && path[2] == 'containers' && !exists?(path)
-            owners |= superusers
+            owners += superusers
           end
         end
 
-        owners.uniq
+        # we don't de-dup this list, because pedant expects to see ["pivotal", "pivotal"] in some cases.
+        owners
       end
 
       def default_acl(acl_path, acl={})
