@@ -15,7 +15,29 @@ module ChefZero
       server.data_store
     end
 
+    def check_api_version(request)
+      version = request.api_version
+      return nil if version.nil? # Not present in headers
+
+      if version.to_i.to_s != version.to_s # Version is not an Integer
+        return json_response(406, { "username" => request.requestor }, -1, -1)
+      elsif version.to_i > MAX_API_VERSION or version.to_i < MIN_API_VERSION
+        response = {
+          "error" => "invalid-x-ops-server-api-version",
+          "message" => "Specified version #{version} not supported",
+          "min_api_version" => MIN_API_VERSION,
+          "max_api_version" => MAX_API_VERSION
+        }
+        return json_response(406, response, version, -1)
+      else
+        return nil
+      end
+    end
+
     def call(request)
+      response = check_api_version(request)
+      return response unless response.nil?
+
       method = request.method.downcase.to_sym
       if !self.respond_to?(method)
         accept_methods = [:get, :put, :post, :delete].select { |m| self.respond_to?(m) }
@@ -173,20 +195,27 @@ module ChefZero
       data_store.exists_dir?(rest_path)
     end
 
-    def error(response_code, error)
-      json_response(response_code, {"error" => [error]})
+    def error(response_code, error, opts={})
+      json_response(response_code, {"error" => [error]}, 0, 0, opts)
     end
 
-    def json_response(response_code, json)
-      already_json_response(response_code, FFI_Yajl::Encoder.encode(json, :pretty => true))
+    def json_response(response_code, json, request_version=0, response_version=0, opts={pretty: true})
+      do_pretty_json = opts[:pretty] && true
+      already_json_response(response_code, FFI_Yajl::Encoder.encode(json, :pretty => do_pretty_json), request_version, response_version)
     end
 
     def text_response(response_code, text)
       [response_code, {"Content-Type" => "text/plain"}, text]
     end
 
-    def already_json_response(response_code, json_text)
-      [response_code, {"Content-Type" => "application/json"}, json_text]
+    def already_json_response(response_code, json_text, request_version=0, response_version=0)
+      header = { "min_version" => MIN_API_VERSION.to_s, "max_version" => MAX_API_VERSION.to_s,
+                 "request_version" => request_version.to_s,
+                 "response_version" => response_version.to_s }
+      [ response_code,
+        { "Content-Type" => "application/json",
+          "X-Ops-Server-API-Version" => FFI_Yajl::Encoder.encode(header) },
+        json_text ]
     end
 
     # To be called from inside rest endpoints
@@ -210,5 +239,39 @@ module ChefZero
     def populate_defaults(request, response)
       response
     end
+
+    def parse_json(json)
+      FFI_Yajl::Parser.parse(json, create_additions: false)
+    end
+
+    def to_json(data)
+      FFI_Yajl::Encoder.encode(data, :pretty => true)
+    end
+
+    def get_data_or_else(request, path, or_else_value)
+      if exists_data?(request, path)
+        parse_json(get_data(request, path))
+      else
+        or_else_value
+      end
+    end
+
+    def list_data_or_else(request, path, or_else_value)
+      if exists_data_dir?(request, path)
+        list_data(request, path)
+      else
+        or_else_value
+      end
+    end
+
+    def hashify_list(list)
+      list.reduce({}) { |acc, obj| acc.merge( obj => {} ) }
+    end
+
+    def policy_name_invalid?(name)
+      !name.is_a?(String) ||
+       name.size > 255 ||
+       name =~ /[+ !]/
+    end
   end
 end
