@@ -125,6 +125,10 @@ module ChefZero
         end
       end
 
+      def cookbook_artifact(name, data, &block)
+        before(chef_server_options[:server_scope]) { cookbook_artifact(name, data, &block) }
+      end
+
       def data_bag(name, data, &block)
         before(chef_server_options[:server_scope]) { data_bag(name, data, &block) }
       end
@@ -149,6 +153,14 @@ module ChefZero
         before(chef_server_options[:server_scope]) { org_member(*usernames) }
       end
 
+      def policy(name, data, &block)
+        before(chef_server_options[:server_scope]) { policy(name, data, &block) }
+      end
+
+      def policy_group(name, data, &block)
+        before(chef_server_options[:server_scope]) { policy_group(name, data, &block) }
+      end
+
       def role(name, data, &block)
         before(chef_server_options[:server_scope]) { role(name, data, &block) }
       end
@@ -215,6 +227,13 @@ module ChefZero
         end
       end
 
+      def cookbook_artifact(name, identifier, data, &block)
+        with_object_path("cookbook_artifacts/#{name}") do
+          ChefZero::RSpec.server.load_data({ 'cookbook_artifact' => { name => { identifier => data } } }, current_org)
+          instance_eval(&block) if block_given?
+        end
+      end
+
       def data_bag(name, data, &block)
         with_object_path("data/#{name}") do
           ChefZero::RSpec.server.load_data({ 'data' => { name => data }}, current_org)
@@ -251,6 +270,20 @@ module ChefZero
         ChefZero::RSpec.server.load_data({ 'members' => usernames }, current_org)
       end
 
+      def policy(name, version, data, &block)
+        with_object_path("policies/#{name}") do
+          ChefZero::RSpec.server.load_data({ 'policies' => { name => { version => data } } }, current_org)
+          instance_eval(&block) if block_given?
+        end
+      end
+
+      def policy_group(name, data, &block)
+        with_object_path("policy_groups/#{name}") do
+          ChefZero::RSpec.server.load_data({ 'policy_groups' => { name => data } }, current_org)
+          instance_eval(&block) if block_given?
+        end
+      end
+
       def role(name, data, &block)
         with_object_path("roles/#{name}") do
           ChefZero::RSpec.server.load_data({ 'roles' => { name => data } }, current_org)
