@@ -45,8 +45,12 @@ require 'chef_zero/endpoints/actor_endpoint'
 require 'chef_zero/endpoints/cookbooks_endpoint'
 require 'chef_zero/endpoints/cookbook_endpoint'
 require 'chef_zero/endpoints/cookbook_version_endpoint'
+require 'chef_zero/endpoints/cookbook_artifacts_cookbook_endpoint'
+require 'chef_zero/endpoints/cookbook_artifacts_cookbook_identifier'
+require 'chef_zero/endpoints/cookbook_artifacts_endpoint'
 require 'chef_zero/endpoints/containers_endpoint'
 require 'chef_zero/endpoints/container_endpoint'
+require 'chef_zero/endpoints/dummy_endpoint'
 require 'chef_zero/endpoints/data_bags_endpoint'
 require 'chef_zero/endpoints/data_bag_endpoint'
 require 'chef_zero/endpoints/data_bag_item_endpoint'
@@ -61,6 +65,8 @@ require 'chef_zero/endpoints/environment_recipes_endpoint'
 require 'chef_zero/endpoints/environment_role_endpoint'
 require 'chef_zero/endpoints/license_endpoint'
 require 'chef_zero/endpoints/node_endpoint'
+require 'chef_zero/endpoints/nodes_endpoint'
+require 'chef_zero/endpoints/node_identifiers_endpoint'
 require 'chef_zero/endpoints/organizations_endpoint'
 require 'chef_zero/endpoints/organization_endpoint'
 require 'chef_zero/endpoints/organization_association_requests_endpoint'
@@ -69,8 +75,14 @@ require 'chef_zero/endpoints/organization_authenticate_user_endpoint'
 require 'chef_zero/endpoints/organization_users_endpoint'
 require 'chef_zero/endpoints/organization_user_endpoint'
 require 'chef_zero/endpoints/organization_validator_key_endpoint'
-require 'chef_zero/endpoints/principal_endpoint'
 require 'chef_zero/endpoints/policies_endpoint'
+require 'chef_zero/endpoints/policy_endpoint'
+require 'chef_zero/endpoints/policy_revisions_endpoint'
+require 'chef_zero/endpoints/policy_revision_endpoint'
+require 'chef_zero/endpoints/policy_groups_endpoint'
+require 'chef_zero/endpoints/policy_group_endpoint'
+require 'chef_zero/endpoints/policy_group_policy_endpoint'
+require 'chef_zero/endpoints/principal_endpoint'
 require 'chef_zero/endpoints/role_endpoint'
 require 'chef_zero/endpoints/role_environments_endpoint'
 require 'chef_zero/endpoints/sandboxes_endpoint'
@@ -85,8 +97,10 @@ require 'chef_zero/endpoints/user_organizations_endpoint'
 require 'chef_zero/endpoints/file_store_file_endpoint'
 require 'chef_zero/endpoints/not_found_endpoint'
 require 'chef_zero/endpoints/version_endpoint'
+require 'chef_zero/endpoints/server_api_version_endpoint'
 
 module ChefZero
+
   class Server
 
     DEFAULT_OPTIONS = {
@@ -101,6 +115,7 @@ module ChefZero
     GLOBAL_ENDPOINTS = [
       '/license',
       '/version',
+      '/server_api_version'
     ]
 
     def initialize(options = {})
@@ -440,6 +455,24 @@ module ChefZero
         end
       end
 
+      if contents['policies']
+        contents['policies'].each_pair do |policy_name, policy_struct|
+          # data_store.create_dir(['organizations', org_name, 'policies', policy_name], "revisions", :recursive)
+          dejsonize_children(policy_struct).each do |revision, policy_data|
+            data_store.set(['organizations', org_name, 'policies', policy_name,
+                            "revisions", revision], policy_data, :create, :create_dir)
+          end
+        end
+      end
+
+      if contents['policy_groups']
+        contents['policy_groups'].each_pair do |group_name, group|
+          group['policies'].each do |policy_name, policy_revision|
+            data_store.set(['organizations', org_name, 'policy_groups', group_name, 'policies', policy_name], FFI_Yajl::Encoder.encode(policy_revision['revision_id'], :pretty => true), :create, :create_dir)
+          end
+        end
+      end
+
       if contents['cookbooks']
         contents['cookbooks'].each_pair do |name_version, cookbook|
           if name_version =~ /(.+)-(\d+\.\d+\.\d+)$/
@@ -478,7 +511,7 @@ module ChefZero
 
     private
 
-    def open_source_endpoints
+    def endpoints
       result = if options[:osc_compat]
         # OSC-only
         [
@@ -522,11 +555,15 @@ module ChefZero
       end
       result + [
         # Both
+        [ "/dummy", DummyEndpoint.new(self) ],
         [ "/organizations/*/clients", ActorsEndpoint.new(self) ],
         [ "/organizations/*/clients/*", ActorEndpoint.new(self) ],
         [ "/organizations/*/cookbooks", CookbooksEndpoint.new(self) ],
         [ "/organizations/*/cookbooks/*", CookbookEndpoint.new(self) ],
         [ "/organizations/*/cookbooks/*/*", CookbookVersionEndpoint.new(self) ],
+        [ "/organizations/*/cookbook_artifacts", CookbookArtifactsEndpoint.new(self) ],
+        [ "/organizations/*/cookbook_artifacts/*", CookbookArtifactsCookbookEndpoint.new(self) ],
+        [ "/organizations/*/cookbook_artifacts/*/*", CookbookArtifactsCookbookIdentifierEndpoint.new(self) ],
         [ "/organizations/*/data", DataBagsEndpoint.new(self) ],
         [ "/organizations/*/data/*", DataBagEndpoint.new(self) ],
         [ "/organizations/*/data/*/*", DataBagItemEndpoint.new(self) ],
@@ -538,9 +575,16 @@ module ChefZero
         [ "/organizations/*/environments/*/nodes", EnvironmentNodesEndpoint.new(self) ],
         [ "/organizations/*/environments/*/recipes", EnvironmentRecipesEndpoint.new(self) ],
         [ "/organizations/*/environments/*/roles/*", EnvironmentRoleEndpoint.new(self) ],
-        [ "/organizations/*/nodes", RestListEndpoint.new(self) ],
+        [ "/organizations/*/nodes", NodesEndpoint.new(self) ],
         [ "/organizations/*/nodes/*", NodeEndpoint.new(self) ],
-        [ "/organizations/*/policies/*/*", PoliciesEndpoint.new(self) ],
+        [ "/organizations/*/nodes/*/_identifiers", NodeIdentifiersEndpoint.new(self) ],
+        [ "/organizations/*/policies", PoliciesEndpoint.new(self) ],
+        [ "/organizations/*/policies/*", PolicyEndpoint.new(self) ],
+        [ "/organizations/*/policies/*/revisions", PolicyRevisionsEndpoint.new(self) ],
+        [ "/organizations/*/policies/*/revisions/*", PolicyRevisionEndpoint.new(self) ],
+        [ "/organizations/*/policy_groups", PolicyGroupsEndpoint.new(self) ],
+        [ "/organizations/*/policy_groups/*", PolicyGroupEndpoint.new(self) ],
+        [ "/organizations/*/policy_groups/*/policies/*", PolicyGroupPolicyEndpoint.new(self) ],
         [ "/organizations/*/principals/*", PrincipalEndpoint.new(self) ],
         [ "/organizations/*/roles", RestListEndpoint.new(self) ],
         [ "/organizations/*/roles/*", RoleEndpoint.new(self) ],
@@ -551,6 +595,7 @@ module ChefZero
         [ "/organizations/*/search", SearchesEndpoint.new(self) ],
         [ "/organizations/*/search/*", SearchEndpoint.new(self) ],
         [ "/version", VersionEndpoint.new(self) ],
+        [ "/server_api_version", ServerAPIVersionEndpoint.new(self) ],
 
         # Internal
         [ "/organizations/*/file_store/**", FileStoreFileEndpoint.new(self) ]
@@ -565,7 +610,7 @@ module ChefZero
 
     def app
       return @app if @app
-      router = RestRouter.new(open_source_endpoints)
+      router = RestRouter.new(endpoints)
       router.not_found = NotFoundEndpoint.new
 
       if options[:single_org]
